==> lxqt-powermanagement_0.17.1.orig.tar.xz: lxqt-powermanagement-0.17.1/src/translations/lxqt-powermanagement_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>فارغة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>تُفرّغ الشحن</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>مشحونة بالكامل</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>تشحن</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>ليثيوم أيون</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>ليثيوم بوليمر</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>ليثيوم فوسفات الحديد</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>حمض الرصاص</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>نيكل كادميوم</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>هيدريد نيكل معدني</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>مجهولة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>بطارية المساعد الرقمي الشخصي</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translatorcomment>تحتاج تنقيح؟</translatorcomment>
        <translation>بطارية للتزويد بطاقة لامنقطعة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>بطارية أساسية</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>بطارية الفأرة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>بطارية لوحة المفاتيح</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>بطارية الفأرة ولوحة المفاتيح</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>بطارية الكمرة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>بطارية الهاتف</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>بطارية الشاشة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>بطارية مجهولة</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>حواريّ</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>معلومات البطارية</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>إدارة الطاقة</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>درجة الحرارة:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>النوع:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>الحالة:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>التصميم للشحن الكامل:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>الشحن الكامل:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>الشحن الآن:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>معدّل الشحن:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>التقنية:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>الفولتية:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>البائع:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>لا بطارية!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>تعذر على لكسكيوت العثور على أي بطارية - عُطّلت المراقبة</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="114"/>
        <source>Power low!</source>
        <translation>البطارية ضعيفة!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="126"/>
        <source>Suspending in %n second(s)</source>
        <translation type="unfinished">
            <numerusform>سيُعلّق الحاسوب بعد %n ثوان</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="129"/>
        <source>Hibernating in %n second(s)</source>
        <translation type="unfinished">
            <numerusform>سيُسبت الحاسوب بعد %n ثوان</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="132"/>
        <source>Shutting down in %n second(s)</source>
        <translation type="unfinished">
            <numerusform>سيُطفأ الحاسوب بعد %n ثوان</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>إدارة الطاقة</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>أنت تشغّل إدارة لكسكيوت للطاقة للمرة الأولى.
يمكنك ضبطها من الإعدادات… </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>اضبط…</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="60"/>
        <source>Configure</source>
        <translation>اضبط</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="62"/>
        <location filename="../trayicon.cpp" line="93"/>
        <source>About</source>
        <translation>عن</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="64"/>
        <source>Disable icon</source>
        <translation>عطّل الأيقونة</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="94"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;إدارة لكسكيوت للطاقة&lt;/b&gt;&lt;br/&gt;  - إدارة طاقة لبيئة سطح مكتب لكسكيوت&lt;/p&gt;&lt;p&gt;  المؤلفون:&lt;br/&gt;  &amp;nbsp; Christian Surlykke و Alec Moskvin&lt;br/&gt;  &amp;nbsp; - وآخرين من مشروعي ريزر ولكسكيوت&lt;/p&gt;&lt;p&gt;  الحقوق محفوظة &amp;copy; ٢٠١٢-٢٠١٤&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="112"/>
        <source>LXQt Power Management info</source>
        <translation>معلومات لكسكيوت لإدارة الطاقة</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="113"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>يمكن تفعيل/إعادة تفعيل أيقونة صينية النظام لإدارة لكسكيوت للطاقة من &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="115"/>
        <source>Configure now</source>
        <translation>اضبط الآن</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_1.1.0.orig.tar.xz: lxqt-powermanagement-1.1.0/src/translations/lxqt-powermanagement_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Empty</source>
        <translation>فارغة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Discharging</source>
        <translation>تُفرّغ الشحن</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="48"/>
        <source>Fully charged</source>
        <translation>مشحونة بالكامل</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="51"/>
        <source>Charging</source>
        <translation>تشحن</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium ion</source>
        <translation>ليثيوم أيون</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium polymer</source>
        <translation>ليثيوم بوليمر</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lithium iron phosphate</source>
        <translation>ليثيوم فوسفات الحديد</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Lead acid</source>
        <translation>حمض الرصاص</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel cadmium</source>
        <translation>نيكل كادميوم</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="70"/>
        <source>Nickel metal hydride</source>
        <translation>هيدريد نيكل معدني</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="73"/>
        <source>Unknown</source>
        <translation>مجهولة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>بطارية المساعد الرقمي الشخصي</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translatorcomment>تحتاج تنقيح؟</translatorcomment>
        <translation>بطارية للتزويد بطاقة لامنقطعة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Primary battery</source>
        <translation>بطارية أساسية</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Mouse battery</source>
        <translation>بطارية الفأرة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard battery</source>
        <translation>بطارية لوحة المفاتيح</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>بطارية الفأرة ولوحة المفاتيح</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Camera battery</source>
        <translation>بطارية الكمرة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Phone battery</source>
        <translation>بطارية الهاتف</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="98"/>
        <source>Monitor battery</source>
        <translation>بطارية الشاشة</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="101"/>
        <source>Unknown battery</source>
        <translation>بطارية مجهولة</translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="111"/>
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="112"/>
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="117"/>
        <source>remaining %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="122"/>
        <source>to full %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>حواريّ</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>معلومات البطارية</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>إدارة الطاقة</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>درجة الحرارة:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>النوع:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>الحالة:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>التصميم للشحن الكامل:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>الشحن الكامل:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>الشحن الآن:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>معدّل الشحن:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>التقنية:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>الفولتية:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>البائع:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>لا بطارية!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>تعذر على لكسكيوت العثور على أي بطارية - عُطّلت المراقبة</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="119"/>
        <source>Power low!</source>
        <translation>البطارية ضعيفة!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Suspending in %n second(s)</source>
        <translation type="unfinished">
            <numerusform>سيُعلّق الحاسوب بعد %n ثوان</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="134"/>
        <source>Hibernating in %n second(s)</source>
        <translation type="unfinished">
            <numerusform>سيُسبت الحاسوب بعد %n ثوان</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="137"/>
        <source>Shutting down in %n second(s)</source>
        <translation type="unfinished">
            <numerusform>سيُطفأ الحاسوب بعد %n ثوان</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>إدارة الطاقة</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>أنت تشغّل إدارة لكسكيوت للطاقة للمرة الأولى.
يمكنك ضبطها من الإعدادات… </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>اضبط…</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="67"/>
        <source>Configure</source>
        <translation>اضبط</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="75"/>
        <source>30 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="79"/>
        <source>1 hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="83"/>
        <source>2 hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="87"/>
        <source>3 hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="91"/>
        <source>4 hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="96"/>
        <source>Pause idleness checks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="101"/>
        <location filename="../trayicon.cpp" line="191"/>
        <source>About</source>
        <translation>عن</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="103"/>
        <source>Disable icon</source>
        <translation>عطّل الأيقونة</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="192"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;إدارة لكسكيوت للطاقة&lt;/b&gt;&lt;br/&gt;  - إدارة طاقة لبيئة سطح مكتب لكسكيوت&lt;/p&gt;&lt;p&gt;  المؤلفون:&lt;br/&gt;  &amp;nbsp; Christian Surlykke و Alec Moskvin&lt;br/&gt;  &amp;nbsp; - وآخرين من مشروعي ريزر ولكسكيوت&lt;/p&gt;&lt;p&gt;  الحقوق محفوظة &amp;copy; ٢٠١٢-٢٠١٤&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="210"/>
        <source>LXQt Power Management info</source>
        <translation>معلومات لكسكيوت لإدارة الطاقة</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="211"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>يمكن تفعيل/إعادة تفعيل أيقونة صينية النظام لإدارة لكسكيوت للطاقة من &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="213"/>
        <source>Configure now</source>
        <translation>اضبط الآن</translation>
    </message>
</context>
</TS>
